@@ -37,11 +37,12 @@ import cryptography.hazmat.primitives.serialization as serialization
 import cryptography.hazmat.backends as backends
 import cryptography.hazmat.primitives.hashes as hashing
 
+from securesystemslib import exceptions
 from securesystemslib import process
 from securesystemslib.gpg.functions import (create_signature, export_pubkey,
     verify_signature, export_pubkeys)
 from securesystemslib.gpg.util import (get_version, is_version_fully_supported,
-    get_hashing_class, parse_packet_header, parse_subpacket_header)
+    get_hashing_class, parse_packet_header, parse_subpacket_header, Version)
 from securesystemslib.gpg.rsa import create_pubkey as rsa_create_pubkey
 from securesystemslib.gpg.dsa import create_pubkey as dsa_create_pubkey
 from securesystemslib.gpg.eddsa import create_pubkey as eddsa_create_pubkey
@@ -59,14 +60,32 @@ from securesystemslib.formats import (GPG_PUBKEY_SCHEMA,
     ANY_PUBKEY_DICT_SCHEMA)
 
 
+class GPGTestUtils:
+    """GPG Test utility class"""
+
+    @staticmethod
+    def ignore_not_found_error(function, path, exc_info):
+        """Callback that ignores FileNotFoundError"""
+        _, error, _ = exc_info
+        if not isinstance(error, FileNotFoundError):
+            raise error
+
+
 @unittest.skipIf(not HAVE_GPG, "gpg not found")
 class TestUtil(unittest.TestCase):
   """Test util functions. """
+
   def test_version_utils_return_types(self):
     """Run dummy tests for coverage. """
-    self.assertTrue(isinstance(get_version(), str))
+    self.assertTrue(isinstance(get_version(), Version))
     self.assertTrue(isinstance(is_version_fully_supported(), bool))
 
+  @patch('securesystemslib.gpg.constants.GPG_VERSION_COMMAND', 'echo "bad"')
+  def test_version_utils_error(self):
+    """Run dummy tests for coverage. """
+    with self.assertRaises(exceptions.UnsupportedLibraryError):
+      get_version()
+
   def test_get_hashing_class(self):
     # Assert return expected hashing class
     expected_hashing_class = [hashing.SHA1, hashing.SHA256, hashing.SHA512]
@@ -503,7 +522,7 @@ class TestGPGRSA(unittest.TestCase):
   def tearDownClass(self):
     """Change back to initial working dir and remove temp test directory. """
     os.chdir(self.working_dir)
-    shutil.rmtree(self.test_dir)
+    shutil.rmtree(self.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
   def test_export_pubkey_error(self):
     """Test correct error is raised if function called incorrectly. """
@@ -664,7 +683,7 @@ class TestGPGDSA(unittest.TestCase):
   def tearDownClass(self):
     """Change back to initial working dir and remove temp test directory. """
     os.chdir(self.working_dir)
-    shutil.rmtree(self.test_dir)
+    shutil.rmtree(self.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
   def test_export_pubkey(self):
     """ export a public key and make sure the parameters are the right ones:
@@ -749,7 +768,7 @@ class TestGPGEdDSA(unittest.TestCase):
   def tearDownClass(self):
     """Change back to initial working dir and remove temp test directory. """
     os.chdir(self.working_dir)
-    shutil.rmtree(self.test_dir)
+    shutil.rmtree(self.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
   def test_gpg_sign_and_verify_object_with_default_key(self):
     """Create a signature using the default key on the keyring """
@@ -798,5 +817,30 @@ class TestGPGEdDSA(unittest.TestCase):
     self.assertTrue(verify_signature(signature, key, test_data))
 
 
+class TestVersion(unittest.TestCase):
+  """Tests for the Version utility class."""
+
+  def test_version_roundtrip_string(self):
+    """Version parses and formats strings correctly."""
+    for value, expected in [
+        ('1.3.0', Version(1, 3, 0)),
+        ('1.3.1', Version(1, 3, 1)),
+        ('1.3.22', Version(1, 3, 22)),
+    ]:
+      self.assertEqual(Version.from_string(value), expected)
+      self.assertEqual(str(expected), value)
+
+  def test_version_from_string_invalid(self):
+    """Version.from_string rejects invalid inputs."""
+    for value in [
+        '1.3',
+        '1.33.0',
+        '1.3.-1',
+        '1.3.1a',
+    ]:
+      with self.assertRaises(ValueError, msg=f"expected error for input '{value}'"):
+        Version.from_string(value)
+
+
 if __name__ == "__main__":
   unittest.main()
